summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorHind-M <hind.montassif@gmail.com>2021-06-08 10:47:45 +0200
committerHind-M <hind.montassif@gmail.com>2021-06-08 10:47:45 +0200
commit2bd2f8134daeb65a9fff730fef75c323320faefb (patch)
treeeff666922b744ebaa5a145157aa0e49ef80dbabc
parentb8b7f4880ceae8d3a65502b86aae0538072253e8 (diff)
Fix incorrect comments relative to Cech
-rw-r--r--src/Cech_complex/concept/SimplicialComplexForCech.h4
-rw-r--r--src/Cech_complex/example/cech_complex_step_by_step.cpp12
2 files changed, 8 insertions, 8 deletions
diff --git a/src/Cech_complex/concept/SimplicialComplexForCech.h b/src/Cech_complex/concept/SimplicialComplexForCech.h
index 00c7df3a..6202fe92 100644
--- a/src/Cech_complex/concept/SimplicialComplexForCech.h
+++ b/src/Cech_complex/concept/SimplicialComplexForCech.h
@@ -47,8 +47,8 @@ struct SimplicialComplexForCech {
};
-} // namespace alpha_complex
+} // namespace cech_complex
} // namespace Gudhi
-#endif // CONCEPT_ALPHA_COMPLEX_SIMPLICIAL_COMPLEX_FOR_ALPHA_H_
+#endif // CONCEPT_CECH_COMPLEX_SIMPLICIAL_COMPLEX_FOR_CECH_H_
diff --git a/src/Cech_complex/example/cech_complex_step_by_step.cpp b/src/Cech_complex/example/cech_complex_step_by_step.cpp
index f59f0293..60ae9712 100644
--- a/src/Cech_complex/example/cech_complex_step_by_step.cpp
+++ b/src/Cech_complex/example/cech_complex_step_by_step.cpp
@@ -24,9 +24,9 @@
#include <map>
// ----------------------------------------------------------------------------
// rips_persistence_step_by_step is an example of each step that is required to
// build a Rips over a Simplex_tree. Please refer to rips_persistence to see
// how to do the same thing with the Rips_complex wrapper for less detailed
// steps.
// ----------------------------------------------------------------------------
@@ -89,7 +89,7 @@ int main(int argc, char* argv[]) {
Proximity_graph prox_graph = Gudhi::compute_proximity_graph<Simplex_tree>(off_reader.get_point_cloud(), max_radius,
Gudhi::Minimal_enclosing_ball_radius());
// Construct the Rips complex in a Simplex Tree
Simplex_tree st;
// insert the proximity graph in the simplex tree
st.insert_graph(prox_graph);
@@ -129,9 +129,9 @@ void program_options(int argc, char* argv[], std::string& off_file_points, Filtr
visible.add_options()("help,h", "produce help message")(
"max-radius,r",
po::value<Filtration_value>(&max_radius)->default_value(std::numeric_limits<Filtration_value>::infinity()),
- "Maximal length of an edge for the Rips complex construction.")(
+ "Maximal length of an edge for the Cech complex construction.")(
"cpx-dimension,d", po::value<int>(&dim_max)->default_value(1),
- "Maximal dimension of the Rips complex we want to compute.");
+ "Maximal dimension of the Cech complex we want to compute.");
po::positional_options_description pos;
pos.add("input-file", 1);
@@ -24,9 +24,9 @@
#include <map>
// ----------------------------------------------------------------------------
-// rips_persistence_step_by_step is an example of each step that is required to
-// build a Rips over a Simplex_tree. Please refer to rips_persistence to see
-// how to do the same thing with the Rips_complex wrapper for less detailed
+// cech_complex_step_by_step is an example of each step that is required to
+// build a Cech over a Simplex_tree. Please refer to cech_complex_example_from_points to see
+// how to do the same thing with the Cech complex wrapper for less detailed
// steps.
// ----------------------------------------------------------------------------
@@ -89,7 +89,7 @@ int main(int argc, char* argv[]) {
Proximity_graph prox_graph = Gudhi::compute_proximity_graph<Simplex_tree>(off_reader.get_point_cloud(), max_radius,
Gudhi::Minimal_enclosing_ball_radius());
- // Construct the Rips complex in a Simplex Tree
+ // Construct the Cech complex in a Simplex Tree
Simplex_tree st;
// insert the proximity graph in the simplex tree